@@ -14,10 +14,32 @@ def cache(tmp_path):
     return Cache(storage=LocalFileStorage(tmp_path))
 
 
+def test_repr(cache):
+    assert "CloudPickleSerializer" in repr(cache.serializer)
+    assert "LocalFileStorage" in repr(cache.storage)
+    assert "Cache" in repr(cache)
+
+
 def test_basic(cache):
 
     counter = 0
 
+    @cache()
+    def get_data():
+        nonlocal counter
+        counter += 1
+        return "abc"
+
+    get_data()
+    get_data()
+
+    assert counter == 1
+
+
+def test_alias(cache):
+
+    counter = 0
+
     @cache.cache()
     def get_data():
         nonlocal counter
@@ -30,11 +52,44 @@ def test_basic(cache):
     assert counter == 1
 
 
+def test_no_parens(cache):
+
+    counter = 0
+
+    @cache
+    def get_data():
+        nonlocal counter
+        counter += 1
+        return "abc"
+
+    get_data()
+    get_data()
+
+    assert counter == 1
+
+
+@pytest.mark.asyncio
+async def test_basic_async(cache):
+
+    counter = 0
+
+    @cache()
+    async def get_data():
+        nonlocal counter
+        counter += 1
+        return "abc"
+
+    await get_data()
+    await get_data()
+
+    assert counter == 1
+
+
 def test_arg_change(cache):
 
     global_key = None
 
-    @cache.cache()
+    @cache()
     def get_data(key):
         nonlocal global_key
         global_key = key
@@ -51,18 +106,18 @@ def test_arg_change(cache):
 
 
 def test_body_change(cache: Cache):
-    @cache.cache()
+    @cache()
     def get_data(key):
         return key
 
-    hash1 = cache.get_key(get_data, None, None, None, None)
+    hash1 = cache._get_key(get_data, None, None, None, None)
 
-    @cache.cache()
+    @cache()
     def get_data(key):
         print("This function has been changed...")
         return key
 
-    hash2 = cache.get_key(get_data, None, None, None, None)
+    hash2 = cache._get_key(get_data, None, None, None, None)
 
     assert hash1 != hash2
 
@@ -71,7 +126,7 @@ def test_serializer_change(cache: Cache):
 
     counter = 0
 
-    @cache.cache(serializer=PickleSerializer())
+    @cache(serializer=PickleSerializer())
     def get_data():
         nonlocal counter
         counter += 1
@@ -81,7 +136,7 @@ def test_serializer_change(cache: Cache):
 
     # now, let's change the serializer
 
-    @cache.cache(serializer=JSONSerializer())
+    @cache(serializer=JSONSerializer())
     def get_data():
         nonlocal counter
         counter += 1
@@ -96,7 +151,7 @@ def test_ignore_args(cache):
 
     counter = 0
 
-    @cache.cache(ignore=["ignore_this"])
+    @cache(ignore=["ignore_this"])
     def get_data(key, ignore_this):
         nonlocal counter
         counter += 1
@@ -115,7 +170,7 @@ def test_no_cache():
 
     cache = NoCache()
 
-    @cache.cache()
+    @cache()
     def get_data():
         nonlocal counter
         counter += 1
@@ -164,10 +219,12 @@ def data():
     yield data1, data2
 
 
-def test_hash():
-    cache = Cache(serializer=CloudPickleSerializer())
+def test_hash(tmp_path):
+    cache = Cache(
+        serializer=CloudPickleSerializer(), storage=LocalFileStorage(tmp_path)
+    )
     for data1, data2 in data():
         assert data1 != data2
-        assert cache.get_key(
+        assert cache._get_key(
             lambda: None, (data1,), None, CloudPickleSerializer(), None
-        ) != cache.get_key(lambda: None, (data2,), None, CloudPickleSerializer(), None)
+        ) != cache._get_key(lambda: None, (data2,), None, CloudPickleSerializer(), None)
